@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: API2.pm,v 1.78 2005/03/21 22:36:36 fredo Exp $
+#   $Id: API2.pm,v 1.79 2005/03/23 16:42:06 fredo Exp $
 #
 #=======================================================================
 
@@ -37,7 +37,7 @@ BEGIN {
 
     use vars qw( $VERSION $seq @FontDirs );
 
-    ($VERSION) = ('$Revision: 1.78 $' =~ /Revision: (\S+)\s/)[0];  # $Date: 2005/03/21 22:36:36 $
+    ($VERSION) = ('$Revision: 1.79 $' =~ /Revision: (\S+)\s/)[0];  # $Date: 2005/03/23 16:42:06 $
 
     @FontDirs = ( (map { "$_/PDF/API2/fonts" } @INC), 
         qw[ /usr/share/fonts /usr/local/share/fonts c:/windows/fonts c:/winnt/fonts ] );
@@ -584,7 +584,7 @@ sub infoMetaAttributes
 {
     my ($self,@attr) = @_;
     if(scalar @attr > 0) {
-        my %at = map { $_ = $_ } (@{$self->{infoMeta}},@attr);
+        my %at = map { $_ => $_ } (@{$self->{infoMeta}},@attr);
         @{$self->{infoMeta}}=(keys %at);
     }
     return(@{$self->{infoMeta}});
@@ -2208,6 +2208,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: API2.pm,v $
+    Revision 1.79  2005/03/23 16:42:06  fredo
+    fixed typo in infoMetaAttributes
+
     Revision 1.78  2005/03/21 22:36:36  fredo
     fix for landscape imports
 
