@@ -8,7 +8,7 @@
 #   A Perl Module Chain to faciliate the Creation and Modification
 #   of High-Quality "Portable Document Format (PDF)" Files.
 #
-#   Copyright 1999-2004 Alfred Reibenschuh <areibens@cpan.org>.
+#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
 #
 #=======================================================================
 #
@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: Outlines.pm,v 1.7 2004/12/16 00:30:52 fredo Exp $
+#   $Id: Outlines.pm,v 1.8 2005/03/14 22:01:05 fredo Exp $
 #
 #=======================================================================
 
@@ -44,7 +44,7 @@ BEGIN {
 
     @ISA = qw(PDF::API2::Outline);
 
-    ( $VERSION ) = '$Revision: 1.7 $' =~ /Revision: (\S+)\s/; # $Date: 2004/12/16 00:30:52 $
+    ( $VERSION ) = '$Revision: 1.8 $' =~ /Revision: (\S+)\s/; # $Date: 2005/03/14 22:01:05 $
 
 }
 
@@ -75,6 +75,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: Outlines.pm,v $
+    Revision 1.8  2005/03/14 22:01:05  fredo
+    upd 2005
+
     Revision 1.7  2004/12/16 00:30:52  fredo
     added no warn for recursion
 
