@@ -8,7 +8,7 @@
 #   A Perl Module Chain to faciliate the Creation and Modification
 #   of High-Quality "Portable Document Format (PDF)" Files.
 #
-#   Copyright 1999-2004 Alfred Reibenschuh <areibens@cpan.org>.
+#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
 #
 #=======================================================================
 #
@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: CJKFont.pm,v 1.12 2004/11/25 15:07:21 fredo Exp $
+#   $Id: CJKFont.pm,v 1.15 2003/04/09 11:13:12 fredo Exp $
 #
 #=======================================================================
 package PDF::API2::Resource::CIDFont::CJKFont;
@@ -50,16 +50,27 @@ BEGIN {
 
     @ISA = qw( PDF::API2::Resource::CIDFont );
 
-    ( $VERSION ) = '$Revision: 1.12 $' =~ /Revision: (\S+)\s/; # $Date: 2004/11/25 15:07:21 $
+    ( $VERSION ) = '$Revision: 1.15 $' =~ /Revision: (\S+)\s/; # $Date: 2003/04/09 11:13:12 $
 
     $fonts = { };
     $cmap = { };
 }
+no warnings qw[ deprecated recursion uninitialized ];
 
 =item $font = PDF::API2::Resource::CIDFont::CJKFont->new $pdf, $cjkname, %options
 
 Returns a cjk-font object.
 
+Traditional Chinese: Ming Ming-Bold Ming-Italic Ming-BoldItalic
+
+Simplified Chinese: Song Song-Bold Song-Italic Song-BoldItalic
+
+Korean: MyungJo MyungJo-Bold MyungJo-Italic MyungJo-BoldItalic
+
+Japanese (Mincho): KozMin KozMin-Bold KozMin-Italic KozMin-BoldItalic
+
+Japanese (Gothic): KozGo KozGo-Bold KozGo-Italic KozGo-BoldItalic
+
 Defined Options:
 
     -encode ... specify fonts encoding for non-utf8 text.
@@ -76,7 +87,14 @@ sub _look_for_font {
         $data=_look_for_font($subs->{$fname}->{-alias});
         foreach my $k (keys %{$subs->{$fname}}) {
           next if($k=~/^\-/);
-          $data->{$k}=$subs->{$fname}->{$k};
+          if(substr($k,0,1) eq '+')
+          {
+              $data->{substr($k,1)}.=$subs->{$fname}->{$k};
+          }
+          else
+          {
+              $data->{$k}=$subs->{$fname}->{$k};
+          }
         }
         $fonts->{$fname}=$data;
         return({%{$data}})
@@ -259,121 +277,96 @@ BEGIN {
 
     $alias={
         'traditional'           => 'adobemingstdlightacro',
+        'traditionalbold'       => 'mingbold',
+        'traditionalitalic'     => 'mingitalic',
+        'traditionalbolditalic' => 'mingbolditalic',
         'ming'                  => 'adobemingstdlightacro',
         
         'simplified'            => 'adobesongstdlightacro',
+        'simplifiedbold'        => 'songbold',
+        'simplifieditalic'      => 'songitalic',
+        'simplifiedbolditalic'  => 'songbolditalic',
         'song'                  => 'adobesongstdlightacro',
 
         'korean'                => 'adobemyungjostdmediumacro',
-        'myungjostdmedium'      => 'adobemyungjostdmediumacro',
-        'hysmyeongjomedium'     => 'adobemyungjostdmediumacro',
+        'koreanbold'            => 'myungjobold',      
+        'koreanitalic'          => 'myungjoitalic',    
+        'koreanbolditalic'      => 'myungjobolditalic',
+        'myungjo'               => 'adobemyungjostdmediumacro',
 
-        'japanese'              => 'kozgopromediumacro',
-        'kozgopromedium'        => 'kozgopromediumacro',
-        'gothicbbbmedium'       => 'kozgopromediumacro',
-        'heiseikakugow5'        => 'kozgopromediumacro',
+        'japanese'              => 'kozminproregularacro',
+        'japanesebold'          => 'kozminbold',
+        'japaneseitalic'        => 'kozminitalic',
+        'japanesebolditalic'    => 'kozminbolditalic',
+        'kozmin'                => 'kozminproregularacro',
+        'kozgo'                 => 'kozgopromediumacro',
 
-        'japanese2'             => 'kozminproregularacro',
-        'kozminproregular'      => 'kozminproregularacro',
-        'ryuminlight'           => 'kozminproregularacro',
-        'heiseiminw3'           => 'kozminproregularacro',
     };
     $subs={
-        'minchow3' => {
-            '-alias'            => 'kozminproregularacro',
-            'fontname'          => 'SerifMincho-W3', 
-            'fontfamily'        => 'SerifMincho',
-            'fontstretch'       => 'Normal',
-            'fontweight'        => '300',
-            'altname'           => 'SerifMinchoW3',
-            'subname'           => 'Regular',
-            'cmap'              => 'japanese',
-            'encode'            => 'euc-jp',
-            'panose'            => "\x01\x05\x02\x0b\x04\x00\x00\x00\x00\x00\x00\x00",
+    # Chinese Traditional (ie. Taiwan) Fonts
+        'mingitalic' => {
+            '-alias'            => 'adobemingstdlightacro',
+            '+fontname'          => ',Italic', 
         },
-        'minchow5' => {
-            '-alias'            => 'kozminproregularacro',
-            'fontname'          => 'SerifMincho-W5', 
-            'fontfamily'        => 'SerifMincho',
-            'fontstretch'       => 'Normal',
-            'fontweight'        => '500',
-            'altname'           => 'SerifMinchoW5',
-            'subname'           => 'Regular',
-            'cmap'              => 'japanese',
-            'encode'            => 'euc-jp',
-            'panose'            => "\x01\x05\x02\x0b\x06\x00\x00\x00\x00\x00\x00\x00",
+        'mingbold' => {
+            '-alias'            => 'adobemingstdlightacro',
+            '+fontname'          => ',Bold', 
         },
-        'minchow7' => {
-            '-alias'            => 'kozminproregularacro',
-            'fontname'          => 'SerifMincho-W7', 
-            'fontfamily'        => 'SerifMincho',
-            'fontstretch'       => 'Normal',
-            'fontweight'        => '700',
-            'altname'           => 'SerifMinchoW7',
-            'subname'           => 'Regular',
-            'cmap'              => 'japanese',
-            'encode'            => 'euc-jp',
-            'panose'            => "\x01\x05\x02\x0b\x08\x00\x00\x00\x00\x00\x00\x00",
+        'mingbolditalic' => {
+            '-alias'            => 'adobemingstdlightacro',
+            '+fontname'          => ',BoldItalic', 
         },
-        'minchow9' => {
-            '-alias'            => 'kozminproregularacro',
-            'fontname'          => 'SerifMincho-W9', 
-            'fontfamily'        => 'SerifMincho',
-            'fontstretch'       => 'Normal',
-            'fontweight'        => '900',
-            'altname'           => 'SerifMinchoW9',
-            'subname'           => 'Regular',
-            'cmap'              => 'japanese',
-            'encode'            => 'euc-jp',
-            'panose'            => "\x01\x05\x02\x0b\x0a\x00\x00\x00\x00\x00\x00\x00",
+    # Chinese Simplified (ie. Mainland China) Fonts
+        'songitalic' => {
+            '-alias'            => 'adobesongstdlightacro',
+            '+fontname'          => ',Italic', 
         },
-        'gothicw3' => {
+        'songbold' => {
+            '-alias'            => 'adobesongstdlightacro',
+            '+fontname'          => ',Bold', 
+        },
+        'songbolditalic' => {
+            '-alias'            => 'adobesongstdlightacro',
+            '+fontname'          => ',BoldItalic', 
+        },
+    # Japanese Gothic (ie. sans) Fonts
+        'kozgoitalic' => {
             '-alias'            => 'kozgopromediumacro',
-            'fontname'          => 'SansGothic-W3', 
-            'fontfamily'        => 'SansGothic',
-            'fontstretch'       => 'Normal',
-            'fontweight'        => '300',
-            'altname'           => 'SansGothicW3',
-            'subname'           => 'Regular',
-            'cmap'              => 'japanese',
-            'encode'            => 'euc-jp',
-            'panose'            => "\x08\x01\x02\x0b\x03\x00\x00\x00\x00\x00\x00\x00",
+            '+fontname'          => ',Italic', 
         },
-        'gothicw5' => {
+        'kozgobold' => {
             '-alias'            => 'kozgopromediumacro',
-            'fontname'          => 'SansGothic-W5', 
-            'fontfamily'        => 'SansGothic',
-            'fontstretch'       => 'Normal',
-            'fontweight'        => '500',
-            'altname'           => 'SansGothicW5',
-            'subname'           => 'Regular',
-            'cmap'              => 'japanese',
-            'encode'            => 'euc-jp',
-            'panose'            => "\x08\x01\x02\x0b\x05\x00\x00\x00\x00\x00\x00\x00",
+            '+fontname'          => ',Bold', 
         },
-        'gothicw7' => {
+        'kozgobolditalic' => {
             '-alias'            => 'kozgopromediumacro',
-            'fontname'          => 'SansGothic-W7', 
-            'fontfamily'        => 'SansGothic',
-            'fontstretch'       => 'Normal',
-            'fontweight'        => '700',
-            'altname'           => 'SansGothicW7',
-            'subname'           => 'Regular',
-            'cmap'              => 'japanese',
-            'encode'            => 'euc-jp',
-            'panose'            => "\x08\x01\x02\x0b\x07\x00\x00\x00\x00\x00\x00\x00",
+            '+fontname'          => ',BoldItalic', 
         },
-        'gothicw9' => {
-            '-alias'            => 'kozgopromediumacro',
-            'fontname'          => 'SansGothic-W9', 
-            'fontfamily'        => 'SansGothic',
-            'fontstretch'       => 'Normal',
-            'fontweight'        => '900',
-            'altname'           => 'SansGothicW9',
-            'subname'           => 'Regular',
-            'cmap'              => 'japanese',
-            'encode'            => 'euc-jp',
-            'panose'            => "\x08\x01\x02\x0b\x09\x00\x00\x00\x00\x00\x00\x00",
+    # Japanese Mincho (ie. serif) Fonts
+        'kozminitalic' => {
+            '-alias'            => 'kozminproregularacro',
+            '+fontname'          => ',Italic', 
+        },
+        'kozminbold' => {
+            '-alias'            => 'kozminproregularacro',
+            '+fontname'          => ',Bold', 
+        },
+        'kozminbolditalic' => {
+            '-alias'            => 'kozminproregularacro',
+            '+fontname'          => ',BoldItalic', 
+        },
+    # Korean Fonts
+        'myungjoitalic' => {
+            '-alias'            => 'adobemyungjostdmediumacro',
+            '+fontname'          => ',Italic', 
+        },
+        'myungjobold' => {
+            '-alias'            => 'adobemyungjostdmediumacro',
+            '+fontname'          => ',Bold', 
+        },
+        'myungjobolditalic' => {
+            '-alias'            => 'adobemyungjostdmediumacro',
+            '+fontname'          => ',BoldItalic', 
         },
     };
 
@@ -389,6 +382,15 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: CJKFont.pm,v $
+    Revision 1.15  2003/04/09 11:13:12  fredo
+    added/fixed proper alias/substitutions
+
+    Revision 1.14  2005/03/14 22:01:07  fredo
+    upd 2005
+
+    Revision 1.13  2004/12/16 00:30:53  fredo
+    added no warn for recursion
+
     Revision 1.12  2004/11/25 15:07:21  fredo
     fixed prototype warning
 
@@ -442,4 +444,4 @@ Acrobat 5:
     MSungStd-Light-Acro         STSongStd-Light-Acro        KozMinPro-Regular-Acro  HYSMyeongJoStd-Medium-Acro
 Acrobat 4:
     MSung-Light                 STSong-Light                HeiseiKakuGo-W5         HYSMyeongJo-Medium
-    MHei-Medium                                             HeiseiMin-W3            HYGoThic-Medium
\ No newline at end of file
+    MHei-Medium                                             HeiseiMin-W3            HYGoThic-Medium
