@@ -8,7 +8,7 @@
 #   A Perl Module Chain to faciliate the Creation and Modification
 #   of High-Quality "Portable Document Format (PDF)" Files.
 #
-#   Copyright 1999-2004 Alfred Reibenschuh <areibens@cpan.org>.
+#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
 #
 #=======================================================================
 #
@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: UniWrap.pm,v 1.1 2004/11/25 19:56:24 fredo Exp $
+#   $Id: UniWrap.pm,v 1.3 2005/03/14 22:01:06 fredo Exp $
 #
 #=======================================================================
 
@@ -43,7 +43,6 @@ BEGIN {
 
     use 5.008;
     use strict;
-    use warnings;
     use base 'Exporter';
 
     use Unicode::UCD;
@@ -51,10 +50,12 @@ BEGIN {
 
     use vars qw($VERSION);
 
-    ( $VERSION ) = '$Revision: 1.1 $' =~ /Revision: (\S+)\s/; # $Date: 2004/11/25 19:56:24 $
+    ( $VERSION ) = '$Revision: 1.3 $' =~ /Revision: (\S+)\s/; # $Date: 2005/03/14 22:01:06 $
 
 }
 
+no warnings qw[ deprecated recursion uninitialized ];
+
 our $DEBUG = 0;
 our $columns = 75;
 
